@@ -1,11 +1,15 @@
 from flask import Flask, request, jsonify
 from handler.handler_helper import Handler
 from handler.flow_data import FlowDataException
+from kubernetes import client, config
+from kubernetes.client.rest import ApiException
 import os
 
 application = Flask(__name__)
 global_workflows = {}
 
+config.load_kube_config()
+api_instance = client.VersionApi()
 
 class App:
 
@@ -72,6 +76,20 @@ class App:
                 }
         return jsonify(response)
 
+    @staticmethod
+    @application.route('/health')
+    def health():
+        try:
+            api_response = api_instance.get_code()
+            response = {
+                "status": "available"
+            }
+        except ApiException as e:
+            response = {
+                "status": "unavailable"
+            }
+        return jsonify(response)
+
     @staticmethod
     def start():
         try:
